| Quade | R Documentation |
Performs Quade's ANCOVA using ranked variables and analysis of residuals. The method fits a linear model of the ranked response on the ranked covariates, and then performs an ANOVA on the residuals of that model.
Quade(data, formula)
data |
A data frame containing the variables specified in the formula. |
formula |
An object of class "formula": a symbolic description of the model to be fitted. The structure should be 'response ~ covariate1 + ... + group'. |
A list containing the following components:
Summary of the linear model regressing the ranked response on the ranked covariates.
The summary of the ANOVA model performed on the residuals.
A data frame of the mean of residuals for each group.
A data frame of the standard deviation of residuals for each group.
The summary of the model fitting residuals on the group.
The original data frame augmented with ranked variables and residuals.
Quade DJJotASA. Rank analysis of covariance. 1967;62(320):1187-200.
Olejnik SF, Algina JJER. A review of nonparametric alternatives to analysis of covariance. 1985;9(1):51-83.
# 1. Create a sample data frame
data <- data.frame(
group = c(1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3),
response = c(16, 60, 82, 126, 137, 44, 67, 87, 100, 142, 17, 28, 105, 149, 160),
covariate1 = c(26, 10, 42, 49, 55, 21, 28, 5, 12, 58, 1, 19, 41, 48, 35),
covariate2 = c(12, 21, 24, 29, 34, 17, 2, 40, 38, 36, 8, 1, 9, 28, 16)
)
# 2. Run the Quade method
results <- Quade(
formula = response ~ covariate1 + covariate2 + group,
data = data
)
# 3. View the results
print(results)
print(results$anova_summary)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.