npANCOVA: npANCOVA: Nonparametric ANCOVA Methods

npANCOVAR Documentation

npANCOVA: Nonparametric ANCOVA Methods

Description

The npANCOVA package provides a collection of functions to implement various nonparametric Analysis of Covariance (ANCOVA) methods.

Details

This package is designed for researchers and statisticians who need to perform ANCOVA when the assumptions of parametric ANCOVA, such as normality of residuals or the homogeneity of regression slopes, are not met.

Key Functions

The main functions provided by the package are:

Burnett_Barr

Implements the Burnett and Barr rank-based method.

Harwell_Serlin

Performs the Harwell and Serlin method using ranked variables.

Hettmansperger_McKean

Applies rank-based residual analysis.

McSweeny_Porter

Performs rank-based ANCOVA with and without interaction.

Puri_Sen_OU

Performs the Puri and Sen method using one covariate with an ubiased variance-covariance matrix.

Puri_Sen_OB

Performs the Puri and Sen method using one covariate with a biased variance-covariance matrix.

Puri_Sen_MU

Performs the Puri and Sen method using multiple covariates with an unbiased variance-covariance matrix.

Puri_Sen_MB

Performs the Puri and Sen method using multiple covariates with a biased variance-covariance matrix.

Quade

Performs Quade's ANCOVA using ranked variables and analysis of residuals.

Shirley

Calculates group and interaction effects based on ranks.

Author(s)

Maintainer: Mina Jahangiri minajahangiri984@gmail.com (ORCID)

Authors:

Other contributors:

  • Anoshirvan Kazemnejad (ORCID) [contributor]

  • Shayan Mostafaei (ORCID) [contributor]

See Also

Useful links:


npANCOVA documentation built on Nov. 9, 2025, 5:06 p.m.

Related to npANCOVA in npANCOVA...