| npANCOVA | R Documentation |
The npANCOVA package provides a collection of functions to implement various nonparametric Analysis of Covariance (ANCOVA) methods.
This package is designed for researchers and statisticians who need to perform ANCOVA when the assumptions of parametric ANCOVA, such as normality of residuals or the homogeneity of regression slopes, are not met.
The main functions provided by the package are:
Burnett_BarrImplements the Burnett and Barr rank-based method.
Harwell_SerlinPerforms the Harwell and Serlin method using ranked variables.
Hettmansperger_McKeanApplies rank-based residual analysis.
McSweeny_PorterPerforms rank-based ANCOVA with and without interaction.
Puri_Sen_OUPerforms the Puri and Sen method using one covariate with an ubiased variance-covariance matrix.
Puri_Sen_OBPerforms the Puri and Sen method using one covariate with a biased variance-covariance matrix.
Puri_Sen_MUPerforms the Puri and Sen method using multiple covariates with an unbiased variance-covariance matrix.
Puri_Sen_MBPerforms the Puri and Sen method using multiple covariates with a biased variance-covariance matrix.
QuadePerforms Quade's ANCOVA using ranked variables and analysis of residuals.
ShirleyCalculates group and interaction effects based on ranks.
Maintainer: Mina Jahangiri minajahangiri984@gmail.com (ORCID)
Authors:
Other contributors:
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.